# FAQ

### What is Fomantic-UI?
Fomantic is a community fork of the popular [Semantic-UI](https://github.com/Semantic-Org/Semantic-UI) framework.

### Why was Fomantic-UI created?
Fomantic was created to continue active development of Semantic-UI and has the intent to be merged back into the master repository once active development can restart. For more info please read the following issues:
- https://github.com/Semantic-Org/Semantic-UI/issues/6109
- https://github.com/Semantic-Org/Semantic-UI/issues/6413

> *EDIT:* Lots has changed since we started this project and we are now starting the development of FUI v3. You can read more about the > v3 proposals [here](https://github.com/fomantic/Fomantic-UI/issues/319).
>
> To be clear merging back into SUI is still our intention, read [this comment](https://github.com/fomantic/Fomantic-UI/issues/319#issuecomment-461736399) for more info

### How do I contribute to Fomantic?
We welcome anyone who wants to help make Fomantic great to come help us. If you are wanting to start contributing please read the [CONTRIBUTING.md](CONTRIBUTING.md) guide before opening any pull request's this helps us keep PR's simple and efficient allowing us to merge and release new features and fixes quicker.

### How do I report an issue with the framework?
If you have an issue with FUI we encourage you to [open an issue](https://github.com/fomantic/Fomantic-UI/issues/new) and let us know, if you just need some simple help join the FUI [Discord server](https://discordapp.com/invite/YChxjJ3) and ask the community for help.

---

## Fomantic-UI Links:
- Website/Documentation: [fomantic-ui.com](https://fomantic-ui.com)
- GitHub Organisation: [github.com/fomantic](https://github.com/fomantic)
- Repository: [github.com/fomantic/Fomantic-UI](https://github.com/fomantic/Fomantic-UI)
  - Docs Repository: [github.com/fomantic/Fomantic-UI-Docs](https://github.com/fomantic/Fomantic-UI-Docs)
  - CSS Repository: [github.com/fomantic/Fomantic-UI-CSS](https://github.com/fomantic/Fomantic-UI-CSS)
  - LESS Repository: [github.com/fomantic/Fomantic-UI-LESS](https://github.com/fomantic/Fomantic-UI-LESS)
  - SASS Repository: [github.com/fomantic/Fomantic-UI-SASS](https://github.com/fomantic/Fomantic-UI-SASS)
  - Branding Repository: [github.com/fomantic/branding](https://github.com/fomantic/branding)
- npm: [npmjs.com/package/fomantic-ui](https://npmjs.com/package/fomantic-ui)
  - CSS Package: [npmjs.com/package/fomantic-ui-css](https://npmjs.com/package/fomantic-ui-css)
  - LESS Package: [npmjs.com/package/fomantic-ui-less](https://npmjs.com/package/fomantic-ui-less)
- JSFiddle: [jsfiddle.net/31d6y7mn](https://jsfiddle.net/31d6y7mn)
- Discord: [discordapp.com/invite/YChxjJ3](https://discordapp.com/invite/YChxjJ3)
- Twitter: [twitter.com/fomanticui](https://twitter.com/fomanticui)
- Medium: [medium.com/@fomantic](https://medium.com/@fomantic)
